---
name: Standard feature request
about: Request a new feature following the standard process
title: 'Feature: [[SUMMARY]]'
labels: enhancement
assignees: ''

---

### Requested change: 

Add the following text to the README and implement the required code changes?

> [[REQUEST]]

### Reason for request:

[[]REASON]
